/* 
   
   Geeks Artificial Neural Network (G.A.N.N) - Read Data
   
   Copyright GNU/GPL 2006 George Delaportas (qtgeo)
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA

*/



//Geeks Read Data (Function)
int GReadData()

{
/*
    //Variables
    int i,j;
    int GANNType,GNeurons,GNInputs;
    int GNOut,GNFT,GNSum,GNBase;
    int GNBits[8],GNWeights[8];
    int *GKDB;
    int Pointer;
    
    //Create A File Pointer
    FILE *FileToOpen;
    
    //Read GKDB
    Pointer=fseek(FileToOpen,0,SEEK_SET);
    //FileToOpen=fopen("GKDB","r");
    
    printf("Point to:%i\n",Pointer);
    
    //Check End Of File
    //while (EOF==0)
    
    //{
    
        //Read Starting Header
        //fscanf(FileToOpen,"%i\n%i\n%i\n",&GANNType,&GNeurons,&GNInputs);
        
        //Fill With Data
        //*(NKDB+0)=GANNType;
        //*(NKDB+1)=GNeurons;
        //*(NKDB+2)=GNInputs;
        
        //Check G.A.N.N Type (0:Binary,1:Sign,2:Sigmoid)
        if (GANNType==0)
        
        {
        
            for (i=0;i<GNeurons;i++)
            
            {
            
                //fscanf(FileToOpen,"%i\n%i\n%i\n%i\n",&GNOut,&GNFT,&GNSum,&GNBase);
                
                //for (j=0;j<GNInputs;j++)
                    //fscanf(FileToOpen,"%i\n",&GNBits[j]);
                
                //for (j=0;j<GNInputs;j++)
                    //fscanf(FileToOpen,"%i\n",&GNWeights[j]);
            
            }
            
            //Fill With Data
            //*(NKDB+3)=GNOut;
            //*(NKDB+4)=GNFT;
            //*(NKDB+5)=GNSum;
            //*(NKDB+6)=GNBase;
            
            //for (j=0;j<8;j++)
                //*(NKDB+7+j)=GNBits[j];
            
            //for (j=0;j<8;j++)
                //*(NKDB+15+j)=GNWeights[j];
            
            //return *NKDB;
        
        }
        
        else if (GANNType==1)
        
        {
        
            //Sign Type
        
        }
        
        else if (GANNType==2)
        
        {
        
            //Sigmoid Type
        
        }
    
    //}
    
    //Close GKDB
    fclose(FileToOpen);
*/
}

/* ------------------------------------------------------------------------ */
